import pygame
import ParticleEmitter
from Resources import *

class Player(pygame.sprite.Sprite):
    """A class for handling all aspects of the player."""
    def __init__(self):
        """Set up the inital player."""
        pygame.sprite.Sprite.__init__(self)
        self.frontimage, self.frontrect = loadImage("astronaut.png")
        self.backimage, self.backrect = loadImage("astronautback.png")
        self.leftimage, self.leftrect = loadImage("astronautleft.png")
        self.rightimage, self.rightrect = loadImage("astronautright.png")

        screen = pygame.display.get_surface()
        self.swidth, self.sheight = screen.get_size()
        self.image, self.rect = self.frontimage, self.frontrect
        self.image = self.image.convert_alpha()
        self.power = 15
        self.move = 1
        self.rect = self.rect.move(250, 150)
        self.lastGood = self.rect
        self.jetemitter = ParticleEmitter.ParticleEmitter(266, 190, angle=90, gravity=0, delay=0, spread=6, color=(255, 255, 255, 100), numToEmit=6, speed=1, lifetime=20, maxParticles=40, fade=12)
        self.jetemitter.start()
        
    def moveUp(self, image, jet):
        if self.rect.top >= 0:
            if self.checkCollide(image):
                self.lastGood = self.rect
                self.image = self.backimage
                if jet:
                    self.rect = self.rect.move((0, -self.move * 2))
                    self.jetemitter.move(self.rect.left+20, self.rect.bottom-8)
                    self.jetemitter.changeAngle(270)
                    self.jetemitter.setMaxParts(40)
                else:
                    self.rect = self.rect.move((0, -self.move))
                    self.jetemitter.setMaxParts(0)
            else:
                self.rect = self.lastGood

    def moveDown(self, image, jet):
        if self.rect.bottom <= self.sheight:
            if self.checkCollide(image):
                self.lastGood = self.rect
                self.image = self.frontimage
                if jet:
                    self.rect = self.rect.move((0, self.move * 2))
                    self.jetemitter.move(self.rect.left+20, self.rect.top+8)
                    self.jetemitter.changeAngle(90)
                    self.jetemitter.setMaxParts(40)
                else:
                    self.rect = self.rect.move((0, self.move))
                    self.jetemitter.setMaxParts(0)
            else:
                self.rect = self.lastGood

    def moveLeft(self, image, jet):
        if self.rect.left >= 0:
            if self.checkCollide(image):
                self.lastGood = self.rect
                self.image = self.rightimage
                if jet:
                    self.rect = self.rect.move((-self.move * 2, 0))
                    self.jetemitter.move(self.rect.right-8, self.rect.top+20)
                    self.jetemitter.changeAngle(0)
                    self.jetemitter.setMaxParts(40)
                else:
                    self.rect = self.rect.move((-self.move, 0))
                    self.jetemitter.setMaxParts(0)
            else:
                self.rect = self.lastGood
                

    def moveRight(self, image, jet):
        if self.rect.right <= self.swidth:
            if self.checkCollide(image):
                self.lastGood = self.rect
                self.image = self.leftimage
                if jet:
                    self.rect = self.rect.move((self.move * 2, 0))
                    self.jetemitter.move(self.rect.left+8, self.rect.top+20)
                    self.jetemitter.changeAngle(180)
                    self.jetemitter.setMaxParts(40)
                else:
                    self.rect = self.rect.move((self.move, 0))
                    self.jetemitter.setMaxParts(0)
            else:
                self.rect = self.lastGood

    def update(self):
        self.jetemitter.update()
        
    def getRect(self):
        return self.rect
        
    def checkCollide(self, image):
        for x in range(self.rect.left - 2, self.rect.right + 2):
            for y in range(self.rect.top + 20, self.rect.bottom + 2):
                if not image.get_at((x, y)) == (255, 255, 255, 255):
                    return False
        return True