import pygame
from Resources import *

class PowerBar(pygame.sprite.Sprite):
    """A class for handling power data and the power meter."""
    def __init__(self, inital=10, drain=0):
        """Initalize the object and all needed images.
        
        Takes inital (default is 10) and drain (default is 0).
        inital is the inital power between 0 & 100.
        drain is the rate at which the power should drain."""
        pygame.sprite.Sprite.__init__(self)
        self.images = []
        for i in range(0, 110, 10):
            filename = "powerbar" + str(i) + ".png"
            temp, unused = loadImage(filename)
            temp = temp.convert_alpha()
            self.images.append(temp)
        self.power = inital
        self.drain = drain
        filename = "powerbar" + str(int(self.power / 10) * 10) + ".png"
        self.image, self.rect = loadImage(filename)
        self.rect = self.rect.move((10, 465))
        self.capacity = 100
    
    def update(self):
        tempPercent = int(self.power / (self.capacity / 10))
        self.image = self.images[tempPercent]
        if self.drain > 0:
            self.decreasePower(self.drain)
        
    def increasePower(self, amount):
        if self.power < self.capacity:
            self.power += amount
        if self.power > self.capacity:
            self.power = self.capacity
        
    def decreasePower(self, amount):
        if self.power > 0:
            self.power -= amount
        if self.power < 0:
            self.power = 0
            
    def increaseCapacity(self, amount):
        self.capacity += amount
    
    def getPower(self):
        return self.power